import React from 'react';
 
import { Card, CardContent, CardMedia, Typography } from '@mui/material';
import { styled, useTheme } from '@mui/system';

const MovieCard = ({ movie, config }) => {
  const truncateFilename = (filename, maxLength) => {
    return filename.length > maxLength
      ? filename.substring(0, maxLength - 3) + '...'
      : filename;
  };

  const theme = useTheme();
  console.log(theme.shadows)
  

  const StyledCard = styled(Card)({
    '&:hover': {
      transform: 'scale(1.05)',
      boxShadow: '0px 6px 16px rgba(0, 0, 0, 0.1)',
      zIndex: 1,
    },
  });

  return (
    <StyledCard>
    <Card
      style={{
        width: '100%',
        height: 200,
        boxShadow: '0 4px 6px rgba(0, 0, 0, 0.1)',
        transition: 'box-shadow 0.3s ease-in-out',
        '&:hover': {
          boxShadow: '0 8px 12px rgba(0, 0, 0, 0.2)',
        },
      }}
    >
      <CardMedia
        component="img"
        height="120"
        image={`${config.Host}/res/${movie.image}`}
      />
      <CardContent>
        <Typography>{truncateFilename(movie.filename, 15)}</Typography>
        <Typography variant="body2" color="textSecondary">
          时长: {movie.duration} min
        </Typography>
      </CardContent>
    </Card>
    </StyledCard>
  );
};

export default MovieCard;